@@ -1,5 +1,5 @@
 # This file is fit for containing basic content check
-
+import lxml.html as lh
 
 def must_contain(resp, pattern):
     """
@@ -11,7 +11,7 @@ def must_contain(resp, pattern):
     :return: None
     :raise: AssertionError
     """
-    assert (pattern in resp.get_data()), "The response does not contain the %s pattern" % pattern
+    assert (pattern in lh.tostring(resp.html)), "The response does not contain the %s pattern" % pattern
 
 
 def must_not_contain(resp, pattern):
@@ -24,5 +24,5 @@ def must_not_contain(resp, pattern):
     :return: None
     :raise: AssertionError
     """
-    assert(pattern not in resp.get_data()), "The response contain the %s pattern" % pattern
+    assert(pattern not in lh.tostring(resp.html)), "The response contain the %s pattern" % pattern
 
